# About
This project exists as an extension of the work done for undegraduate math research on plane partitions. It utilizes the speed and correctness of rust with the usability of python to create a python library that can be used for working with plane partitions.

# Installation
This step requires only a valid installation of pip. It is recommended to use a managed python environment for this step.
To install, simply type `pip3 install plane-partitions` into a terminal, or add `!pip install plane-partitions` at the top of an ipython notebook.
Once this step is done, `import plane_partitons` should return no errors, and you should have access to the package.

# Contributing
Once the undegraduate research is concluded, the project will be released under an open-source licence and be open to contributions. Contact [Jimmy Ostler](https://github.com/LordGoatius/) for more information.

